
## CATO-CLI - mutation.policy.socketLan.removeRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeRule) for documentation on this operation.

### Usage for mutation.policy.socketLan.removeRule:

`catocli mutation policy socketLan removeRule -h`

`catocli mutation policy socketLan removeRule <json>`

`catocli mutation policy socketLan removeRule "$(cat < removeRule.json)"`

`catocli mutation policy socketLan removeRule '{"socketLanPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "socketLanRemoveRuleInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.policy.socketLan.removeRule ####
`accountId` [ID] - (required) N/A 
`socketLanPolicyMutationInput` [SocketLanPolicyMutationInput] - (optional) N/A 
`socketLanRemoveRuleInput` [SocketLanRemoveRuleInput] - (required) N/A 
